import React__default, { useState, useCallback } from 'react';
import { ThemeProvider } from '@rescui/ui-contexts';
import Input from '@rescui/input';
import Button from '@rescui/button';
import { CloseIcon, ErrorIcon } from '@rescui/icons';
import styles from './full-search.module.pcss.js';
import { useSearch } from '../search-wrapper/use-search.js';
import { ResultsList } from './results-list/results-list.js';

const FullSearch = ({
  searchString,
  killSearch
}) => {
  const [inputValue, setInputValue] = useState(searchString);
  const {
    hits,
    placeholder
  } = useSearch(inputValue, 75);
  const clearSearch = useCallback(() => {
    setInputValue('');
  }, []);
  const handleInputChange = useCallback(e => {
    setInputValue(e.target.value);
  }, [inputValue]);
  return React__default.createElement(ThemeProvider, {
    theme: 'light'
  }, React__default.createElement("div", {
    className: styles.fullSearch,
    tabIndex: 1000
  }, React__default.createElement("div", {
    className: styles.header
  }, React__default.createElement("div", {
    className: styles.closeSearch
  }, React__default.createElement(Button, {
    mode: 'clear',
    size: 'l',
    icon: React__default.createElement(CloseIcon, null),
    onClick: killSearch
  })), React__default.createElement("div", {
    className: styles.wrapper
  }, React__default.createElement(Input, {
    placeholder: 'Search',
    value: inputValue,
    onClear: clearSearch,
    onChange: handleInputChange,
    clearIcon: React__default.createElement(ErrorIcon, null),
    size: 'l',
    autoFocus: true
  }))), React__default.createElement("div", {
    className: styles.wrapper
  }, inputValue && React__default.createElement(ResultsList, {
    placeholder: placeholder,
    hits: hits
  }))));
};

export { FullSearch };
