import React__default, { useContext, useCallback } from 'react';
import classNames from 'classnames';
import { useTextStyles } from '@rescui/typography';
import Switcher from '@rescui/switcher';
import SearchContext from '../../search-wrapper/search-context.js';
import getExtendedHits from './get-extended-hits.js';
import { Chapters } from '../chapters/chapters.js';
import styles from './hit-list.module.pcss.js';

const HitList = ({
  hits
}) => {
  const textCn = useTextStyles();
  const extendedHits = getExtendedHits(hits);
  const {
    matching,
    matchingOptions,
    setMatching
  } = useContext(SearchContext);
  const handleSwitcherChange = useCallback(value => {
    setMatching(value);
  }, []);
  return React__default.createElement(React__default.Fragment, null, React__default.createElement("div", {
    className: styles.switcher
  }, React__default.createElement(Switcher, {
    value: matching,
    onChange: handleSwitcherChange,
    options: matchingOptions,
    size: 'xs'
  })), extendedHits.map(({
    title,
    snippet,
    chapters = [],
    url,
    breadcrumb
  }, pageIndex) => {
    const isHitWithChapters = chapters.length > 0;
    return React__default.createElement("div", {
      className: styles.hitList,
      key: pageIndex
    }, React__default.createElement("h3", {
      className: textCn('rs-h3')
    }, React__default.createElement("a", {
      className: classNames(styles.titleLink, textCn('rs-link', {
        mode: 'clear',
        hardness: 'hard'
      })),
      href: url,
      dangerouslySetInnerHTML: {
        __html: title
      }
    })), isHitWithChapters ? React__default.createElement(Chapters, {
      chapters: chapters,
      hitIndex: pageIndex
    }) : React__default.createElement("div", {
      className: classNames(textCn('rs-text-2')),
      dangerouslySetInnerHTML: {
        __html: snippet
      }
    }));
  }));
};

export { HitList };
